@@ -24,7 +24,7 @@ static CalBackendWCAPClass *parent_class = NULL;
 
 #define d(x)
 
-G_DEFINE_TYPE (CalBackendWCAPEvents, cal_backend_wcap_events,  CAL_BACKEND_WCAP_TYPE);
+G_DEFINE_TYPE (CalBackendWCAPEvents, cal_backend_wcap_events,  CAL_BACKEND_WCAP_TYPE)
 
 static gboolean
 compare_dates (ECalComponentDateTime *adt, ECalComponentDateTime *bdt)
