@@ -14,7 +14,7 @@
 #define SUNONE_CONFIG_LISTENER_H
 
 #include <glib-object.h>
-#include <e-util/e-account-list.h>
+#include <libedataserver/e-account-list.h>
 #include <libedataserver/e-source.h>
 #include <libedataserver/e-source-list.h>
 #include "lib/sunone-connection.h"
