@@ -21,7 +21,7 @@
 #include <libecal/e-cal.h>
 #include <libecal/e-cal-component.h>
 #include <libecal/e-cal-time-util.h>
-#include <e-util/e-time-utils.h>
+#include <libedataserver/e-time-utils.h>
 #include <misc/e-cell-renderer-combo.h>
 #include "lib/sunone-account.h"
 #include "lib/sunone-util.h"
@@ -141,7 +141,7 @@ sunone_invitation_list_destroy (GtkObject *object)
 		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
-G_DEFINE_TYPE (SunOneInvitationList, sunone_invitation_list, GTK_TYPE_VBOX);
+G_DEFINE_TYPE (SunOneInvitationList, sunone_invitation_list, GTK_TYPE_VBOX)
 
 static icalcomponent *
 toplevel_with_zones (SunOneInvitationList *list, ECalComponent *comp)
